ComplExLiteral
==============

.. currentmodule:: pykeen.models

.. autoclass:: ComplExLiteral
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ComplExLiteral.hpo_default
      ~ComplExLiteral.loss_default_kwargs

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: loss_default_kwargs
